# ColorDescriptor Installation
The ColorDescriptor content description implementation hinges on the 
ColorDescriptor package that can be found at:

    http://koen.me/research/colordescriptors/
    
Provided that this is being used for non-commercial purposes, or a license has
been acquired, this site provides a method of downloading a ZIP archive of 
the necessary binaries (for Windows, Max OSX and Linux systems) and required 
python IO module.

## Setup
1. Add the unzipped directory to the PYTHONPATH to allow access to the 
    DescriptorsIO.py module.
2. Add the system specific sub-directory to the PATH depending on your platform.
    